==> jc-1.4.0.tar.gz: gnu/java/security/provider/SHA.h <==
// public class gnu.java.security.provider.SHA

// class file dependencies
// @dep_class 17c25ff8531f1ffd gnu_java_security_provider_SHA
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cc2047cad8dcf75e java_security_MessageDigest
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_security_MessageDigest

#include "java/security/MessageDigest.h"

#ifndef _JC_gnu_java_security_provider_SHA_H_
#define _JC_gnu_java_security_provider_SHA_H_

// Forward structure declarations
struct _jc_gnu_java_security_provider_SHA$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_SHA$sub_refs	_jc_gnu_java_security_provider_SHA$sub_refs;
typedef struct _jc_gnu_java_security_provider_SHA$sub_nonrefs	_jc_gnu_java_security_provider_SHA$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA$refs	_jc_gnu_java_security_provider_SHA$refs;
typedef struct _jc_gnu_java_security_provider_SHA$nonrefs	_jc_gnu_java_security_provider_SHA$nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA$object	_jc_gnu_java_security_provider_SHA$object;

typedef const struct _jc_gnu_java_security_provider_SHA$vmethods	_jc_gnu_java_security_provider_SHA$vmethods;
typedef const struct _jc_gnu_java_security_provider_SHA$vtable	_jc_gnu_java_security_provider_SHA$vtable;
typedef const struct _jc_gnu_java_security_provider_SHA$vtype	_jc_gnu_java_security_provider_SHA$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_SHA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern void _jc_gnu_java_security_provider_SHA$method$_init$37f253f3d3f1c938(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_gnu_java_security_provider_SHA$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_provider_SHA$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern _jc_byte_array *_jc_gnu_java_security_provider_SHA$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern jint _jc_gnu_java_security_provider_SHA$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern void _jc_gnu_java_security_provider_SHA$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern void _jc_gnu_java_security_provider_SHA$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, jbyte);
extern void _jc_gnu_java_security_provider_SHA$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_security_provider_SHA$method$munch$544fb750c2ab693c(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
extern void _jc_gnu_java_security_provider_SHA$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineUpdate$d2f85b5d32010900;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$munch$544fb750c2ab693c;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_SHA$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, jbyte);
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_byte_array *, jint, jint);
	void	(*munch$544fb750c2ab693c)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_SHA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
	_jc_java_security_MessageDigest$vmethods	java_security_MessageDigest;
	_jc_gnu_java_security_provider_SHA$vmethods	gnu_java_security_provider_SHA;
};

// Vtype
struct _jc_gnu_java_security_provider_SHA$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_SHA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA$sub_refs {
	_jc_int_array	*W;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA$refs {
    _jc_gnu_java_security_provider_SHA$sub_refs	gnu_java_security_provider_SHA;
    _jc_java_security_MessageDigest$sub_refs	java_security_MessageDigest;
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA$sub_nonrefs {
	jlong	bytecount;
	jint	H0;
	jint	H1;
	jint	H2;
	jint	H3;
	jint	H4;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
    _jc_java_security_MessageDigest$sub_nonrefs	java_security_MessageDigest;
    _jc_gnu_java_security_provider_SHA$sub_nonrefs	gnu_java_security_provider_SHA;
};

// Object instance structure
struct _jc_gnu_java_security_provider_SHA$object {
	_jc_gnu_java_security_provider_SHA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_SHA$vtype	*vtype;
	_jc_gnu_java_security_provider_SHA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_SHA$vtype _jc_gnu_java_security_provider_SHA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_SHA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_SHA$class_object;

#endif	/* _JC_gnu_java_security_provider_SHA_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/SHA.h <==
// public class gnu.java.security.provider.SHA

// class file dependencies
// @dep_class 17c25ff8531f1ffd gnu_java_security_provider_SHA
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cc2047cad8dcf75e java_security_MessageDigest
// @dep_class 7d8127440fb7dad2 java_security_MessageDigestSpi

// header file dependencies
// @dep_header java_security_MessageDigest

#include "java/security/MessageDigest.h"

#ifndef _JC_gnu_java_security_provider_SHA_H_
#define _JC_gnu_java_security_provider_SHA_H_

// Forward structure declarations
struct _jc_gnu_java_security_provider_SHA$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_SHA$sub_refs	_jc_gnu_java_security_provider_SHA$sub_refs;
typedef struct _jc_gnu_java_security_provider_SHA$sub_nonrefs	_jc_gnu_java_security_provider_SHA$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA$refs	_jc_gnu_java_security_provider_SHA$refs;
typedef struct _jc_gnu_java_security_provider_SHA$nonrefs	_jc_gnu_java_security_provider_SHA$nonrefs;
typedef struct _jc_gnu_java_security_provider_SHA$object	_jc_gnu_java_security_provider_SHA$object;

typedef const struct _jc_gnu_java_security_provider_SHA$vmethods	_jc_gnu_java_security_provider_SHA$vmethods;
typedef const struct _jc_gnu_java_security_provider_SHA$vtable	_jc_gnu_java_security_provider_SHA$vtable;
typedef const struct _jc_gnu_java_security_provider_SHA$vtype	_jc_gnu_java_security_provider_SHA$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_SHA$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$_init$37f253f3d3f1c938(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_security_provider_SHA$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_provider_SHA$method$engineDigest$af4966fb4f066ce0(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_security_provider_SHA$method$engineGetDigestLength$74fcf1ae739bccab(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$engineReset$216e0febda0be220(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$engineUpdate$807e0421d3c3a314(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, jbyte) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$engineUpdate$d2f85b5d32010900(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$munch$544fb750c2ab693c(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_SHA$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineDigest$af4966fb4f066ce0;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineGetDigestLength$74fcf1ae739bccab;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineReset$216e0febda0be220;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineUpdate$807e0421d3c3a314;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$engineUpdate$d2f85b5d32010900;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$munch$544fb750c2ab693c;
extern _jc_method _jc_gnu_java_security_provider_SHA$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_SHA$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*engineDigest$af4966fb4f066ce0)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
	jint	(*engineGetDigestLength$74fcf1ae739bccab)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
	void	(*engineReset$216e0febda0be220)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
	void	(*engineUpdate$807e0421d3c3a314)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, jbyte) _JC_JCNI_ATTR;
	void	(*engineUpdate$d2f85b5d32010900)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*munch$544fb750c2ab693c)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_SHA$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_SHA$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_MessageDigestSpi$vmethods	java_security_MessageDigestSpi;
	_jc_java_security_MessageDigest$vmethods	java_security_MessageDigest;
	_jc_gnu_java_security_provider_SHA$vmethods	gnu_java_security_provider_SHA;
};

// Vtype
struct _jc_gnu_java_security_provider_SHA$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_SHA$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA$sub_refs {
	_jc_int_array	*W;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA$refs {
    _jc_gnu_java_security_provider_SHA$sub_refs	gnu_java_security_provider_SHA;
    _jc_java_security_MessageDigest$sub_refs	java_security_MessageDigest;
    _jc_java_security_MessageDigestSpi$sub_refs	java_security_MessageDigestSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_SHA$sub_nonrefs {
	jlong	bytecount;
	jint	H0;
	jint	H1;
	jint	H2;
	jint	H3;
	jint	H4;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_SHA$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_MessageDigestSpi$sub_nonrefs	java_security_MessageDigestSpi;
    _jc_java_security_MessageDigest$sub_nonrefs	java_security_MessageDigest;
    _jc_gnu_java_security_provider_SHA$sub_nonrefs	gnu_java_security_provider_SHA;
};

// Object instance structure
struct _jc_gnu_java_security_provider_SHA$object {
	_jc_gnu_java_security_provider_SHA$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_SHA$vtype	*vtype;
	_jc_gnu_java_security_provider_SHA$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_SHA$vtype _jc_gnu_java_security_provider_SHA$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_SHA, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_SHA$class_object;

#endif	/* _JC_gnu_java_security_provider_SHA_H_ */
